searchData={"items":[{"type":"module","title":"LiveViewResponsive","doc":"Media queries for responsive design in Phoenix LiveView.","ref":"LiveViewResponsive.html"},{"type":"module","title":"Example - LiveViewResponsive","doc":"","ref":"LiveViewResponsive.html#module-example"},{"type":"module","title":"With `<.media_query>` component - LiveViewResponsive","doc":"```elixir\ndefmodule ExampleAppWeb.Example do\n  use Phoenix.Component\n\n  import LiveViewResponsive\n\n  def example(assigns) do\n    ~H\"\"\"\n    <.media_query max_width={1224}>\n       You are on a tablet or mobile \n    </.media_query>\n    <.media_query min_width={1225}>\n       You are on a desktop or laptop \n      <.media_query min_width={1500}>\n         You also have a huge screen \n      </.media_query>\n    </.media_query>\n    \"\"\"\n  end\nend\n```","ref":"LiveViewResponsive.html#module-with-media_query-component"},{"type":"module","title":"With media query assigns - LiveViewResponsive","doc":"```elixir\ndefmodule ExampleAppWeb.ExampleComponent do\n  use ExampleAppWeb, :live_component\n\n  use LiveViewResponsive\n\n  def mount(socket) do\n    socket =\n      socket\n      |> assign_media_query(:tablet_or_mobile, max_width: \"1224px\")\n      |> assign_media_query(:desktop_or_laptop, min_width: \"1225px\")\n      |> assign_media_query(:portrait, orientation: \"portrait\")\n\n    {:ok, socket}\n  end\n\n  @impl true\n  def render(assigns) do\n    ~H\"\"\"\n     \n      <.live_view_responsive myself={@myself} />\n\n       \n         Device test \n         \n          You are on a desktop or laptop\n         \n         \n          You are on a tablet or mobile phone\n         \n         \n          You are in\n          <%= if assigns.portrait, do: \"portrait\", else: \"landscape\" %>\n          orientation\n         \n       \n     \n    \"\"\"\n  end\nend\n```","ref":"LiveViewResponsive.html#module-with-media-query-assigns"},{"type":"function","title":"LiveViewResponsive.assign_media_query/3","doc":"","ref":"LiveViewResponsive.html#assign_media_query/3"},{"type":"function","title":"LiveViewResponsive.live_view_responsive/1","doc":"","ref":"LiveViewResponsive.html#live_view_responsive/1"},{"type":"function","title":"LiveViewResponsive.media_query/1","doc":"","ref":"LiveViewResponsive.html#media_query/1"},{"type":"module","title":"LiveViewResponsive.Breakpoints","doc":"Generates breakpoints for live_view_responsive package.\n\nUsage:\n\n```elixir\ndefmodule ExampleApp.LiveViewResponsive do\n  use LiveViewResponsive.Breakpoints, [\n    mobile: [max_width: 700],\n    tablet: [min_width: 701, max_width: 1200],\n    desktop: [min_width: 1201],\n  ]\nend\n```\n\nThen you can `import` or `use` the module `ExampleApp.LiveViewResponsive` in your components.\n\nFor each breakpoint a new component named `{breakpoint}_media_query` is generated, for example:\n\n```elixir\n<.mobile_media_query>\n  You are on mobile\n</.mobile_media_query>\n```\n\nAnd a function named `assign_{breakpoint}_media_query` is created, for example:\n\n```elixir\nsocket\n|> assign_mobile_media_query(initial: true)\n|> assign_tablet_media_query()\n```","ref":"LiveViewResponsive.Breakpoints.html"},{"type":"function","title":"LiveViewResponsive.Breakpoints.compile_breakpoints/2","doc":"","ref":"LiveViewResponsive.Breakpoints.html#compile_breakpoints/2"},{"type":"module","title":"LiveViewResponsive.Components.LiveViewResponsive","doc":"Module containing `<.live_view_responsive>` component.","ref":"LiveViewResponsive.Components.LiveViewResponsive.html"},{"type":"function","title":"LiveViewResponsive.Components.LiveViewResponsive.live_view_responsive/1","doc":"Renders `LiveViewResponsiveHook` hook required for `LiveViewResponsive.Core.assign_media_query/3`.","ref":"LiveViewResponsive.Components.LiveViewResponsive.html#live_view_responsive/1"},{"type":"function","title":"Example - LiveViewResponsive.Components.LiveViewResponsive.live_view_responsive/1","doc":"```elixir\ndef render(assigns) do\n  ~H\"\"\"\n   \n    <.live_view_responsive myself={@myself} />\n    ...\n   \n  \"\"\"\nend\n```","ref":"LiveViewResponsive.Components.LiveViewResponsive.html#live_view_responsive/1-example"},{"type":"function","title":"Attributes - LiveViewResponsive.Components.LiveViewResponsive.live_view_responsive/1","doc":"* `myself` (`:any`) (required) - @myself assign from the parent component.","ref":"LiveViewResponsive.Components.LiveViewResponsive.html#live_view_responsive/1-attributes"},{"type":"module","title":"LiveViewResponsive.Components.MediaQuery","doc":"Module containing `<.media_query>` component.","ref":"LiveViewResponsive.Components.MediaQuery.html"},{"type":"function","title":"LiveViewResponsive.Components.MediaQuery.media_query/1","doc":"A component which shows or hides children on the front-end side based on a media query.\n\nUses the `LiveViewResponsiveMediaQueryHook` hook.","ref":"LiveViewResponsive.Components.MediaQuery.html#media_query/1"},{"type":"function","title":"Example - LiveViewResponsive.Components.MediaQuery.media_query/1","doc":"```elixir\ndefmodule ExampleAppWeb.Example do\n  use Phoenix.Component\n\n  import LiveViewResponsive\n\n  def example(assigns) do\n    ~H\"\"\"\n    <.media_query max_width={1224}>\n       You are on a tablet or mobile \n    </.media_query>\n    <.media_query min_width={1225}>\n       You are on a desktop or laptop \n      <.media_query min_width={1500}>\n         You also have a huge screen \n      </.media_query>\n    </.media_query>\n    \"\"\"\n  end\nend\n```","ref":"LiveViewResponsive.Components.MediaQuery.html#media_query/1-example"},{"type":"function","title":"Attributes - LiveViewResponsive.Components.MediaQuery.media_query/1","doc":"* `query` (`:string`) - Custom media query. When used, other attributes are ignored.\n* `all` (`:boolean`)\n* `grid` (`:boolean`)\n* `aural` (`:boolean`)\n* `braille` (`:boolean`)\n* `handheld` (`:boolean`)\n* `print` (`:boolean`)\n* `projection` (`:boolean`)\n* `screen` (`:boolean`)\n* `tty` (`:boolean`)\n* `tv` (`:boolean`)\n* `embossed` (`:boolean`)\n* `orientation` (`:any`) - Must be one of `:portrait`, `:landscape`, `\"portrait\"`, or `\"landscape\"`.\n* `scan` (`:any`) - Must be one of `:progressive`, `:interlace`, `\"progressive\"`, or `\"interlace\"`.\n* `aspect_ratio` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `min_aspect_ratio` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `max_aspect_ratio` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `device_aspect_ratio` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `min_device_aspect_ratio` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `max_device_aspect_ratio` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `height` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `min_height` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `max_height` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `device_height` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `min_device_height` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `max_device_height` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `width` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `min_width` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `max_width` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `device_width` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `min_device_width` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `max_device_width` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `color` (`:boolean`)\n* `min_color` (`:integer`)\n* `max_color` (`:integer`)\n* `color_index` (`:boolean`)\n* `min_color_index` (`:integer`)\n* `max_color_index` (`:integer`)\n* `monochrome` (`:boolean`)\n* `min_monochrome` (`:integer`)\n* `max_monochrome` (`:integer`)\n* `resolution` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `min_resolution` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `max_resolution` (`:any`) - String or number. When number is passed, suffix `px` is added.\n* `rest` (`:any`) - String or number. When number is passed, suffix `px` is added.","ref":"LiveViewResponsive.Components.MediaQuery.html#media_query/1-attributes"},{"type":"module","title":"LiveViewResponsive.Core","doc":"Core LiveViewResponsive module.","ref":"LiveViewResponsive.Core.html"},{"type":"function","title":"LiveViewResponsive.Core.assign_media_query/3","doc":"Assigns a boolean value that is automatically updated based on whether the media query matches.\n\nRequires `LiveViewResponsive.Components.LiveViewResponsive.live_view_responsive/1` to be rendered in the template and `use LiveViewResponsive` definition in the live component module.\n\nWhen information about all matching media queries is received from the front-end for the first time, the assign `@live_view_responsive_synced` is set to true.","ref":"LiveViewResponsive.Core.html#assign_media_query/3"},{"type":"function","title":"Options - LiveViewResponsive.Core.assign_media_query/3","doc":"- Media types and features from [media_types_and_features.ex](https://github.com/arturz/live_view_responsive/tree/main/lib/live_view_responsive/constants/media_types_and_features.ex).\n- `initial` - initial value of media query assign before information about matching is received. By default `false`.","ref":"LiveViewResponsive.Core.html#assign_media_query/3-options"},{"type":"function","title":"Example - LiveViewResponsive.Core.assign_media_query/3","doc":"```elixir\n@impl true\ndef mount(socket) do\n  socket =\n    socket\n    |> assign_media_query(:tablet_or_mobile, max_width: \"1224px\", initial: true)\n    |> assign_media_query(:desktop_or_laptop, min_width: \"1225px\")\n    |> assign_media_query(:portrait, orientation: \"portrait\")\n\n  {:ok, socket}\nend\n```","ref":"LiveViewResponsive.Core.html#assign_media_query/3-example"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}